
/**************************************************************************
*
*
* - File              : main.c
*
*
* - Supported devices : Atmega2561.
*
*
*****************************************************************************/

#include <ctype.h>
#include "main.h"
#include <avr/io.h>
#include <homelab/delay.h>
#include <homelab/pin.h>
#include <homelab/module/lcd_gfx.h>


// Global buffer. Defined SoftPWM.c
volatile unsigned char compbuff[CHMAX];

pin led_red    = PIN(C, 5);
pin led_yellow = PIN(C, 4);
pin led_green  = PIN(C, 3);
 
pin button1 = PIN(C, 0);
pin button2 = PIN(C, 1);
pin button3 = PIN(C, 2);


//
// The program entry point.
//
int main(void)
{
  unsigned char rxdata = 0;
  signed char direction = -1;


    // Seab LEDid tkorda
	pin_setup_output(led_red);
	pin_setup_output(led_yellow);
	pin_setup_output(led_green);
 
	// Seab nupud tkorda
	pin_setup_input_with_pullup(button1);
	pin_setup_input_with_pullup(button2);
	pin_setup_input_with_pullup(button3);
 
	// Llitab LEDid vlja
	pin_set(led_green);
	pin_set(led_yellow);
	pin_set(led_red);

	// Ekraani seadistamine
	lcd_gfx_init();
 
	// LCD ekraani puhastamine
	lcd_gfx_clear();

	lcd_gfx_backlight(true); 
 
	// Kursori (nhtamatu) ekraani keskele viimine
	lcd_gfx_goto_char_xy(3, 2);
 
	// Teksti kuvamine
	lcd_gfx_write_string("SoftPWM");

    
  	InitSoftPWM();
  	

  	while(1)
  	{
   	  
 
		// Nupp S1 alla vajutatud
		if(!pin_get_debounced_value(button1))
		{
			// Kiiruse suurendamine
			if(rxdata < 0xFF)
			{
				rxdata++;
			}
			pin_clear(led_green);
			
		}
 
		// Nupp S2 alla vajutatud
	    if(!pin_get_debounced_value(button2))
		{
			// Kiiruse vhendamine
			if(rxdata > 0x00)
			{
				rxdata--;
			}
			pin_clear(led_yellow);

		}
 
		// Nupp S3 alla vajutatud
		if(!pin_get_debounced_value(button3))
		{
			//Prlemissuuna muutmine
			if(direction == 1)
			{
				direction = -1;
			}
			else
			{
				direction = 1;		
			}

		}
		
		pin_set(led_green);
		pin_set(led_yellow);		
		
		//Mootori juhtimine
		dcmotor_drive(0, direction, rxdata);
		sw_delay_ms(5);

		/*
		dcmotor_drive(0, 1, 0xFF);
		sw_delay_ms(500);
		dcmotor_drive(0, -1, 0xFF);
		sw_delay_ms(500);
		*/
       
  	}
}

//
// Funktsioon mootori juhtimiseks.
//
void dcmotor_drive(unsigned char index, signed char direction, unsigned char speed) 
{
	switch (index)
	{
		case 0:
			if(direction == 1)
			{
				compbuff[6] = 0x00;
				compbuff[7] = speed;
			}
			if(direction == -1)
			{
				compbuff[7] = 0x00;
				compbuff[6] = speed;				
			}
			
			break;
 
		
		case 1:  //OK
			
			if(direction == 1)
			{
				compbuff[0] = 0x00;
				compbuff[1] = speed;
			}
			if(direction == -1)
			{
				compbuff[0] = speed;
				compbuff[1] = 0x00;
			}
			
			break;

		case 2: //OK
			
			if(direction == 1)
			{
				compbuff[4] = 0x00;
				compbuff[5] = speed;
			}
			if(direction == -1)
			{
				compbuff[5] = 0x00;
				compbuff[4] = speed;				
			}
			
			break;

		case 3: //OK
			
			if(direction == 1)
			{
				compbuff[2] = 0x00;
				compbuff[3] = speed;
			}
			if(direction == -1)
			{
				compbuff[3] = 0x00;
				compbuff[2] = speed;
			}
			
			break;
 
		//default:
		
		
	}
}





